@@ -201,6 +201,7 @@ class Trinket:
             200217: Source.RARE_MOB,  # Blazing Essence
             200563: Source.RARE_MOB,  # Primal Ritual Shell
             200859: Source.RARE_MOB,  # Seasoned Hunter's Trophy
+            198407: Source.WORLD_QUEST,  # Azure Arcanic Amplifier
         }
 
         if self.item_id in item_mapping.keys():
@@ -267,6 +268,9 @@ class Trinket:
             ):
                 levels += ItemLevel.ITEM_LEVELS[self.source][season]  # type: ignore
 
+            elif self.source == Source.WORLD_QUEST:
+                levels = ItemLevel.ITEM_LEVELS[self.source][season] # type: ignore
+
             elif self.source == Source.PROFESSION:
                 levels += ItemLevel.ITEM_LEVELS[self.source][season]  # type: ignore
                 epic_cutoff = 382
@@ -456,6 +460,9 @@ class Trinket:
 
             if self.source == Source.RARE_MOB:
                 return [Season.SEASON_1]
+
+            if self.item_id in (198407,):
+                return [Season.SEASON_1]
         # TODO: add more logic to present more trinkets as season trinkets
 
         return []
